(by-pattern key)Returns a SCAN result sequence, partitioned to 1000 items per batch. Needs to be called inside car/wcar.
Returns an eduction.
Returns a SCAN result sequence, partitioned to 1000 items per batch. Needs to be called inside car/wcar. Returns an eduction.
(default-keys-generator memento-space-prefix
memento-secondary-index-prefix
anon-key-strat)Generates keys to be used when working with Redis.
Generates keys to be used when working with Redis.
(active-invalidation-key this token)Key for one leased active invalidation record.
Key for one leased active invalidation record.
(cache-wildcard-key this cache-name)A wildcard (glob) key that will return all keys used by a particular cache.
A wildcard (glob) key that will return all keys used by a particular cache.
(entry-sec-index-key this entry-key)ID for the hash that maps an entry to its current secondary indexes.
ID for the hash that maps an entry to its current secondary indexes.
(segment-wildcard-key this cache-name segment)A wildcard (glob) key that will return all keys used by a particular memoized function. Segment is memento.base.Segment.
A wildcard (glob) key that will return all keys used by a particular memoized function. Segment is memento.base.Segment.
(sec-id-epochs-key this)Key for the hash of secondary index key -> latest invalidation epoch.
Key for the hash of secondary index key -> latest invalidation epoch.
(segment-key? this cache-name segment k)Returns true if key belongs to the Segment
Returns true if key belongs to the Segment
(sec-indexes-key this)ID for the SET that houses all base keys of secondary indexes.
ID for the SET that houses all base keys of secondary indexes.
(base-wildcard-keys this)Returns a coll of wildcard keys that will select all keys of all Memento Redis caches that use this kind of Keys Generator, used for nuking all the caches.
Returns a coll of wildcard keys that will select all keys of all Memento Redis caches that use this kind of Keys Generator, used for nuking all the caches.
(active-invalidation-records-key this)Key for the set of active invalidation record keys.
Key for the set of active invalidation record keys.
(sec-index-id-key this id)ID for the SET that houses all the keys that get invalidated by id.
ID for the SET that houses all the keys that get invalidated by id.
(cache-key? this cache-name k)Returns true if key belongs to the named cache
Returns true if key belongs to the named cache
(epoch-key this)Key for the Redis secondary-invalidation epoch.
Key for the Redis secondary-invalidation epoch.
(entry-key? this cache-name k)Returns true if key is a concrete cache entry key.
Returns true if key is a concrete cache entry key.
(entry-key this cache-name segment args-key)A concrete key for an entry. Segment is memento.base.Segment.
A concrete key for an entry. Segment is memento.base.Segment.
(wildcard key)Creates a wildcard key from a list key. It will select all keys with additional elements in the list. It will not select the key itself.
Need to use REAL list, not list*. Metadata on the list is ignored as it screws up wildcarding
Escapes bytes ? * [ \ from provided key.
Creates a wildcard key from a list key. It will select all keys with additional elements in the list. It will not select the key itself. Need to use REAL list, not list*. Metadata on the list is ignored as it screws up wildcarding Escapes bytes ? * [ \ from provided key.
(wildcard-exact-length base-key)Creates a SCAN pattern that selects keys whose serialized list count equals exactly (inc (count base-key)) and whose first (count base-key) elements match base-key. In other words: only descendants of base-key with exactly one additional element.
Throws if the target count byte would be a glob metachar (? * [ ), since the pattern would then be ambiguous. Cache keys are short enough that this is effectively unreachable.
Need to use REAL list, not list*. Metadata is ignored.
Escapes bytes ? * [ \ from provided key.
Creates a SCAN pattern that selects keys whose serialized list count equals exactly (inc (count base-key)) and whose first (count base-key) elements match base-key. In other words: only descendants of base-key with exactly one additional element. Throws if the target count byte would be a glob metachar (? * [ \), since the pattern would then be ambiguous. Cache keys are short enough that this is effectively unreachable. Need to use REAL list, not list*. Metadata is ignored. Escapes bytes ? * [ \ from provided key.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |