memento.redis.sec-index


active-invalidation-fade-msclj

How long an active invalidation survives without a refresh after its process dies.

How long an active invalidation survives without a refresh after its process dies.
sourceraw docstring

active-invalidation-refresh-msclj

source

active-invalidationsclj

source

all-domainsclj

Redis domains keyed by connection and secondary-index namespace. Domains are retained so off-heap entries remain invalidatable after cache objects are collected.

Redis domains keyed by connection and secondary-index namespace. Domains are retained
so off-heap entries remain invalidatable after cache objects are collected.
sourceraw docstring

all-indexesclj

Stores pairs of connection + indexes key seen

Stores pairs of connection + indexes key seen
sourceraw docstring

clean-up-scriptclj

source

finalize-domain-invalidation!clj

(finalize-domain-invalidation! [conn :as domain] ids token invalidate?)
source

finalize-invalidation!clj

(finalize-invalidation! {:keys [token]} invalidate?)
source

finalize-invalidation-scriptclj

source

finish-load-scriptclj

source

keys-param-for-sec-idxclj

(keys-param-for-sec-idx kg k sec-ids)

Script to insert an entry with secondary indexes has special KEYS structure of [k, indexes-key, epoch-key, sec-id-epochs-key, active-invalidation-records-key, entry-sec-index-key, id-key1, id-key2, ....].

Script to insert an entry with secondary indexes has special KEYS structure of
[k, indexes-key, epoch-key, sec-id-epochs-key, active-invalidation-records-key,
entry-sec-index-key, id-key1, id-key2, ....].
sourceraw docstring

maintenance-stepclj

(maintenance-step all-indexes)

Perform maintenance multithreaded, one future per each connection after the first.

Perform maintenance multithreaded, one future per each connection after the first.
sourceraw docstring

refresh-active-invalidations!clj

(refresh-active-invalidations!)
source

register-domain!clj

(register-domain! conn keygen)
source

removed-expired-keysclj

(removed-expired-keys conn set-key)

Looks at 20 keys in master index then look at up to 20 of their entries. If more than 20% were expired, repeat the process.

Looks at 20 keys in master index then look at up to 20 of their entries. If more than 20%
were expired, repeat the process.
sourceraw docstring

start-domain-invalidation!clj

(start-domain-invalidation! [conn :as domain] ids token)
source

start-invalidation!clj

(start-invalidation! ids)
source

start-invalidation-scriptclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries