memento.redis.util


del-keys-by-patternclj

(del-keys-by-pattern conn key)
source

kv-by-patternclj

(kv-by-pattern conn key key-xf-fn)
(kv-by-pattern conn key key-pred key-xf-fn)

Returns a map with all the keys matching the pattern and their values. The final map has keys transformed by key-xf-fn

Returns a map with all the keys matching the pattern and their values. The final
map has keys transformed by key-xf-fn
sourceraw docstring

kv-by-pattern-rawclj

(kv-by-pattern-raw conn key key-pred key-xf-fn val-xf-fn)

Like kv-by-pattern but reads values with car/parse-raw so each value is a byte[] (or nil for missing keys). Applies val-xf-fn to each raw byte[]; pairs for which val-xf-fn returns EntryMeta/absent are elided from the result.

Used by cache.clj/asMap to expose decoded entry values where val-xf-fn decodes Redis entry envelopes. Nil is a legitimate cached value; EntryMeta/absent is the explicit sentinel for in-flight load markers (0x03) and ignored values.

Like kv-by-pattern but reads values with car/parse-raw so each value is a
byte[] (or nil for missing keys). Applies val-xf-fn to each raw byte[]; pairs
for which val-xf-fn returns EntryMeta/absent are elided from the result.

Used by cache.clj/asMap to expose decoded entry values where val-xf-fn
decodes Redis entry envelopes. Nil is a legitimate cached value; EntryMeta/absent
is the explicit sentinel for in-flight load markers (0x03) and ignored values.
sourceraw docstring

nuke-keyspaceclj

(nuke-keyspace conn keygen)

Nukes keyspace

Nukes keyspace
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries