How long an active invalidation survives without a refresh after its process dies.
How long an active invalidation survives without a refresh after its process dies.
Redis domains keyed by connection and secondary-index namespace. Domains are retained so off-heap entries remain invalidatable after cache objects are collected.
Redis domains keyed by connection and secondary-index namespace. Domains are retained so off-heap entries remain invalidatable after cache objects are collected.
Stores pairs of connection + indexes key seen
Stores pairs of connection + indexes key seen
(finalize-domain-invalidation! [conn :as domain] ids token invalidate?)(keys-param-for-sec-idx kg k sec-ids)Script to insert an entry with secondary indexes has special KEYS structure of [k, indexes-key, epoch-key, sec-id-epochs-key, active-invalidation-records-key, entry-sec-index-key, id-key1, id-key2, ....].
Script to insert an entry with secondary indexes has special KEYS structure of [k, indexes-key, epoch-key, sec-id-epochs-key, active-invalidation-records-key, entry-sec-index-key, id-key1, id-key2, ....].
(maintenance-step all-indexes)Perform maintenance multithreaded, one future per each connection after the first.
Perform maintenance multithreaded, one future per each connection after the first.
(removed-expired-keys conn set-key)Looks at 20 keys in master index then look at up to 20 of their entries. If more than 20% were expired, repeat the process.
Looks at 20 keys in master index then look at up to 20 of their entries. If more than 20% were expired, repeat the process.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |